
{% load i18n %}

<div style="max-width: 300px">
    <b>{{ object.full_name }}</b> <br />
    {{ object.mobile }} <br />
    <b>{% trans 'Address' %}:</b> {{ object.address|default:'---' }} <br />
    <b>{% trans 'Delivery method' %}:</b> {{ object.delivery_method }} <br />
    <b>{% trans 'Payment method' %}:</b> {{ object.payment_method }}
</div>
