
from django.utils.translation import gettext_lazy as _


DAYS_OF_WEEK = [
    _('Monday'),
    _('Tuesday'),
    _('Wednesday'),
    _('Thursday'),
    _('Friday'),
    _('Saturday'),
    _('Sunday')
]

ORDER_STATUS_NEW = 'new'

PAYMENT_METHOD_PRIVAT24 = 'privat24'
