
{% load i18n thumbnail %}


{% for item in object.items.all %}

    {% thumbnail item.product_logo "40" crop="top" as img %}
        <img src="{{ img.url }}" class="pull-left" style="margin-right: 5px">
    {% empty %}
        ----
    {% endthumbnail %}

    <a href="{{ item.product.get_absolute_url }}" target="_blank">
        {{ item.product_name }} {% if item.product_code %}({{ item.product_code }}){% endif %}
    </a> <br />
    <b>{{ item.qty }} x {{ item.product_printable_price }}</b> <br />

    {% if is_clothes_app_enabled %}
        <div class="row" style="min-width: 420px">
            {% for size in item.clothe_sizes.all %}
                <table class="table table-condensed" style="width: 200px;float: left;margin-right: 5px">
                    {% for label, value in size.get_values %}
                        <tr>
                            <td><b>{{ label }}</b></td>
                            <td>{{ value }}</td>
                        </tr>
                    {% endfor %}
                </table>
            {% endfor %}
        </div>
    {% endif %}

    <div class="clearfix" style="margin: 5px 0;"></div>

    <hr />
{% endfor %}

<b>{% trans 'Total' %}:</b> {{ object.printable_total }}
